Constants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
audioMimeTypes
→ const Map<
String, String> -
contentFocus
→ const Map<
String, String> -
imageMimeTypes
→ const Map<
String, String> - locale → const Map
- path → const String
- schemaTypePath → const String
-
schemaTypes
→ const Map<
String, String> -
validatorTypes
→ const Map<
String, String> -
videoMimeTypes
→ const Map<
String, String>